/**
 * @file main.c
 * @brief Main routine
 *
 * @section License
 *
 * Copyright (C) 2010-2015 Oryx Embedded SARL. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 1.6.4
 **/

//Dependencies
#include <stdlib.h>
#include "stm32f4xx.h"
#include "stm32f4_discovery.h"
//#include "stm32f4_discovery_lcd.h"
#include "os_port.h"
#include "core/net.h"
#include "drivers/stm32f4x7_eth.h"
#include "drivers/lan8720.h"
#include "dhcp/dhcp_client.h"
#include "ipv6/slaac.h"
#include "ftp/ftp_server.h"
#include "http/http_server.h"
#include "http/mime.h"

#include "yarrow.h"

#include "str.h"
#include "path.h"
#include "debug.h"

#include "Com_UART.h"
#include "rampabus.h"
#include "Herramienta.h"
#include "config_ini.h"

/*
//Application configuration
#define APP_MAC_ADDR "00-AB-CD-EF-04-07"

#define APP_USE_DHCP ENABLED

#define APP_IPV4_HOST_ADDR "10.0.0.155"

#define APP_IPV4_SUBNET_MASK "255.255.255.0"
#define APP_IPV4_DEFAULT_GATEWAY "10.0.0.1"
#define APP_IPV4_PRIMARY_DNS "8.8.8.8"
#define APP_IPV4_SECONDARY_DNS "8.8.4.4"
*/

#define APP_USE_SLAAC ENABLED
#define APP_IPV6_LINK_LOCAL_ADDR "fe80::407"
#define APP_IPV6_PREFIX "2001:db8::"
#define APP_IPV6_PREFIX_LENGTH 64
#define APP_IPV6_GLOBAL_ADDR "2001:db8::407"
#define APP_IPV6_ROUTER "fe80::1"
#define APP_IPV6_PRIMARY_DNS "2001:4860:4860::8888"
#define APP_IPV6_SECONDARY_DNS "2001:4860:4860::8844"

#define APP_HTTP_MAX_CONNECTIONS 4
//#define HTTP_SERVER_BASIC_AUTH_SUPPORT ENABLED

/*
//Forward declaration of functions
uint_t ftpServerCheckUserCallback(FtpClientConnection *connection,
   const char_t *user);

uint_t ftpServerCheckPasswordCallback(FtpClientConnection *connection,
   const char_t *user, const char_t *password);

uint_t ftpServerGetFilePermCallback(FtpClientConnection *connection,
   const char_t *user, const char_t *path);
*/	 
//Forward declaration of functions
error_t httpServerCgiCallback(HttpConnection *connection,
   const char_t *param);

error_t httpServerUriNotFoundCallback(HttpConnection *connection,
   const char_t *uri);
	 
HttpAccessStatus httpServerAuthCallback(HttpConnection *connection,
   const char_t *user, const char_t *uri);

//Global variables
uint_t lcdLine = 0;
uint_t lcdColumn = 0;

uint_t OnValue = 0;
uint8_t led1=0,led2=0,led3=0;
uint8_t next=0;

xSemaphoreHandle xSemaphoreRampabus;
xSemaphoreHandle xSemaphoreSensores110;
//xSemaphoreHandle xSemaphoreHor;
//xQueueHandle xQueueLuz1;
//xQueueHandle xQueueLuz2;
//xQueueHandle xQueueHor;

//uint8_t sensor4[8];
//uint8_t sensor3[6];
//uint8_t sensorhor[8];
uint8_t sensortodo[22];
float_t tran_time=0.0;

DhcpClientSettings dhcpClientSettings;
DhcpClientCtx dhcpClientContext;
SlaacSettings slaacSettings;
SlaacContext slaacContext;

//FtpServerSettings ftpServerSettings;
//FtpServerContext ftpServerContext;

HttpServerSettings httpServerSettings;
HttpServerContext httpServerContext;
HttpConnection httpConnections[APP_HTTP_MAX_CONNECTIONS];

YarrowContext yarrowContext;
uint8_t seed[32];

/**
 * @brief Set cursor location
 * @param[in] line Line number
 * @param[in] column Column number
 **/

void lcdSetCursor(uint_t line, uint_t column)
{
   lcdLine = MIN(line, 10);
   lcdColumn = MIN(column, 20);
}


/**
 * @brief Write a character to the LCD display
 * @param[in] c Character to be written
 **/

void lcdPutChar(char_t c)
{
   if(c == '\r')
   {
      lcdColumn = 0;
   }
   else if(c == '\n')
   {
      lcdColumn = 0;
      lcdLine++;
   }
   else if(lcdLine < 10 && lcdColumn < 20)
   {
      //Display current character
      LCD_DisplayChar(lcdLine * 24, lcdColumn * 16, c);

      //Advance the cursor position
      if(++lcdColumn >= 20)
      {
         lcdColumn = 0;
         lcdLine++;
      }
   }
}


/**
 * @brief I/O initialization
 **/

void ioInit(void)
{
   GPIO_InitTypeDef GPIO_InitStructure;

   //LED configuration
   STM_EVAL_LEDInit(LED3);
   STM_EVAL_LEDInit(LED4);
   STM_EVAL_LEDInit(LED5);
   STM_EVAL_LEDInit(LED6);

   //Clear LEDs
   STM_EVAL_LEDOff(LED3);
   STM_EVAL_LEDOff(LED4);
   STM_EVAL_LEDOff(LED5);
   STM_EVAL_LEDOff(LED6);

   //Initialize user button
   STM_EVAL_PBInit(BUTTON_USER, BUTTON_MODE_GPIO);

   //Enable GPIOE clock
   RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOE, ENABLE);

   //Configure PE2 (PHY_RST) pin as an output
   GPIO_InitStructure.GPIO_Pin = GPIO_Pin_2;
   GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
   GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
   GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
   GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
   GPIO_Init(GPIOE, &GPIO_InitStructure);

   //Reset PHY transceiver (hard reset)
   GPIO_ResetBits(GPIOE, GPIO_Pin_2);
   sleep(10);
   GPIO_SetBits(GPIOE, GPIO_Pin_2);
   sleep(10);
}


/**
 * @brief User task
 **/

void userTask(void *param){
		
	Capsula cap ;
	CapFile capfi;
	uint8_t bbuf[50];
	//uint8_t bbfu2[100];
	uint8_t xquebuf[8];
	portTickType tick;
	//uint16_t  rpin;	
	uint16_t d_cur=0;
//	uint16_t t1,h1,t2;
//	uint16_t AR,AG,AB,AUV,ATEMP1,ATEMP2,AHR1;
	
	TRACE_ERROR("*******************ENTRANDO A USERTASK*********************\r\n");
	sleep(8000);
	//DMA_Cmd(DMA1_Stream1,DISABLE);
	PulgarRed();
	
//	TNV_Cabecera_INI_FIN(0);
		
	while(1){
		
		while(next){
			if(OnValue==0)xSemaphoreTake( xSemaphoreRampabus, ( portTickType ) portMAX_DELAY );
			TNV_ObtenerTarea(bbuf,&capfi);
			DesModularMem(&cap,bbuf,sizeof(cap),0);
			
			if(cap.Direccion==110 && cap.Funcion==3){

				Config_USART3_DMA_RX(Multiplo(14,5));
				
				cap.Direccion=110;//direccion para el sensor led de prueba
				cap.Funcion=3;
				cap.Grupos=esclavo;
				cap.Tamdatas=0;//en bytes
				cap.Normas=inicio;
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
			
				xSemaphoreTake(xSemaphoreUSART3,(portTickType)portMAX_DELAY);//espera al que isr dma ponga dato de tamao mencionado
				//xQueueSendToBack(xQueueRampabus,RX_Buf,( portTickType ) portMAX_DELAY);
				//DesModularMem(xquebuf,RX_Buf,8,0);
				//xQueueSendToBack(xQueueLuz1,xquebuf,(portTickType)portMAX_DELAY);
				//DesModularMem(xQueueLuz2,xquebuf,6,8);
				//xQueueSendToBack(xQueueLuz2,xquebuf,(portTickType)portMAX_DELAY);
			
				//DesModularMem(sensor4,RX_Buf,sizeof(sensor4),0);
				//DesModularMem(sensor3,RX_Buf,sizeof(sensor3),8);
				d_cur=0;
				MemSecuencial(sensortodo,RX_Buf,14,&d_cur);
				
	
				//TRACE_ERROR("Valor Rojo=%d -- Verde=%d -- AZUL=%d -- UV=%d -- T1=%d -- T2=%d --HR1=%d\r\n",AR,AG,AB,AUV,ATEMP1,ATEMP2,AHR1);
			
				osDelayTask(150);
			}
			else if(cap.Direccion==70 && cap.Funcion==4){
				Config_USART3_DMA_RX(Multiplo(10,5));
				
				cap.Direccion=70;//direccion para el utr del horno de induccion
				cap.Funcion=4;
				cap.Grupos=esclavo;
				cap.Tamdatas=0;
				cap.Normas=inicio;
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
				
				xSemaphoreTake(xSemaphoreUSART3,(portTickType)portMAX_DELAY);//espera al que isr dma ponga dato de tamao mencionado
				
				//DesModularMem(sensorhor,RX_Buf,sizeof(sensorhor),0);
				MemSecuencial(sensortodo,RX_Buf,8,&d_cur);
				
				//xSemaphoreTake(xSemaphoreHor,(portTickType)portMAX_DELAY);
				xSemaphoreTake(xSemaphoreSensores110,(portTickType)portMAX_DELAY);
				
				osDelayTask(150);
			}
		
			
			//else if....
			
			
			
			
			
			
/*
			if(cap.Funcion==1){
				
				Config_USART3_DMA_RX(5);
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
				tick = xTaskGetTickCount();
				xSemaphoreTake( xSemaphoreUSART3, ( portTickType ) portMAX_DELAY );
				
				DesModularMem(&rpin,RX_Buf,2,0);
				osDelayTask(15);
				//TRACE_ERROR("VAlor de direccion=%d y rpin=%x\r\n",cap.Direccion,rpin);
				if(cap.Direccion==150 && rpin==0xfafb){
					GPIOD->ODR^=GPIO_Pin_12;
					memset(RX_Buf,0,5);
				}
				else if(cap.Direccion==151 && rpin==0xfafb){
					GPIOD->ODR^=GPIO_Pin_13;
					memset(RX_Buf,0,5);
				}
				tick=xTaskGetTickCount()-tick;
				vTaskDelayUntil(&tick,1/portTICK_RATE_MS);
				tran_time=(float_t)tick;
				tick=0;
			}
			else if(cap.Funcion==2){
				
				Config_USART3_DMA_RX(Multiplo(11,5));
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
				
				
				xSemaphoreTake( xSemaphoreUSART3, ( portTickType ) portMAX_DELAY );
			
				xQueueSendToBack(xQueueRampabus,RX_Buf,( portTickType ) portMAX_DELAY);
			
				//DesModularMem(&cap2,RX_Buf,sizeof(cap2),0);
				//DesModularMem(&t1,RX_Buf,2,5);
				//DesModularMem(&h1,RX_Buf,2,7);
				//DesModularMem(&t2,RX_Buf,2,9);
				
				//TRACE_INFO("SE TRANSMITE QUEUE RAMPABUS dir=%d -- t1=%d -- h1=%d -- t2=%d\r\n",cap2.Direccion,t1,h1,t2);
				
				memset(RX_Buf,0,15);
				
			}
			
			next=TNV_Sig();
			//sleep(100);
			osDelayTask(100);
*/		
			next=TNV_Sig();
			//sleep(100);
			osDelayTask(100);

		}
		TNV_Cabecera_INI_FIN(0);
		
		next=1;
		
		
	}
	
	
  
     
   
}


/**
 * @brief LED blinking task
 **/

void blinkTask(void *parameters)
{
	/*
	uint8_t buf[50];
	Capsula cap;
	uint16_t t1;
	uint16_t h1;
	uint16_t t2;
   //Endless loop
   while(1)
   {
     if(pdTRUE==xQueueReceive(xQueueRampabus,buf,( portTickType ) portMAX_DELAY)){
			DesModularMem(&cap,buf,sizeof(cap),0);
			DesModularMem(&t1,buf,2,5);
			DesModularMem(&h1,buf,2,7);
			DesModularMem(&t2,buf,2,9);
		 
			//TRACE_INFO("SE TRANSMITE QUEUE RAMPABUS dir %d -- t1=%d -- h1=%d -- t2=%d\r\n",cap.Direccion,t1,h1,t2);
		 }
		 
		//	adcValue++;
     // sleep(100);
		 osDelayTask(30);
   }
	 
	 */
}


/**
 * @brief Main entry point
 * @return Unused value
 **/

int_t main(void)
{
   error_t error;
   NetInterface *interface;
   OsTask *task;
   MacAddr macAddr;
	 FIL fi;
	 char buf[80];
	
		
#if (APP_USE_DHCP == DISABLED)
   Ipv4Addr ipv4Addr;
#endif
#if (APP_USE_SLAAC == DISABLED)
   Ipv6Addr ipv6Addr;
#endif
	
	
   //Initialize kernel
  osInitKernel();
	
	
	 
   //Configure debug UART
  debugInit(115200);
	
	Proceder_USART3_DMA();
	 
   //Start-up message
   TRACE_INFO("\r\n");
   TRACE_INFO("**********************************\r\n");
   TRACE_INFO("*** CycloneTCP FTP Server Demo ***\r\n");
   TRACE_INFO("**********************************\r\n");
   TRACE_INFO("Copyright: 2010-2015 Oryx Embedded SARL\r\n");
   TRACE_INFO("Compiled: %s %s\r\n", __DATE__, __TIME__);
   TRACE_INFO("Target: STM32F407\r\n");
   TRACE_INFO("\r\n");

   //Configure I/Os
   ioInit();
	 sleep(5000);
	 
	 
	 vSemaphoreCreateBinary( xSemaphoreRampabus );
	 vSemaphoreCreateBinary( xSemaphoreSensores110);
	 //vSemaphoreCreateBinary( xSemaphoreHor);
	
	// xQueueLuz1=xQueueCreate((unsigned portBASE_TYPE)1,(unsigned portBASE_TYPE)10);//50 bytes
	// xQueueLuz2=xQueueCreate((unsigned portBASE_TYPE)1,(unsigned portBASE_TYPE)8);
	// xQueueHor=xQueueCreate((unsigned portBASE_TYPE)1,(unsigned portBASE_TYPE)10);
	 
	 OnValue=0;
   
	 
   error = fsInit();
   //Any error to report?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize file system!\r\n");
   }
	  
	 Cargar_Archivo_Ini(&fi,"config.cfg");
	 
		
	 Campo_Valor(&fi,"RAMPABUS-485","baudio",buf);
	 BAUDIO=atoi(buf);
	 Config_USART3(BAUDIO);
	// Proceder_USART3_DMA();
	 
	 CargarArchivo("datapool.brb",&hfile);
	 
	 /*
	 AgregarTarea(&cap,sizeof(cap));
	 return 0;
	 */
	  error = yarrowInit(&yarrowContext);
   //Any error to report?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize PRNG!\r\n");
   }

   //Properly seed the PRNG
   error = yarrowSeed(&yarrowContext, seed, sizeof(seed));
   //Any error to report?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to seed PRNG!\r\n");
   }
	 
	 
   //TCP/IP stack initialization
   error = netInit();
   //Any error to report?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize TCP/IP stack!\r\n");
   }
	 

   //Configure the first Ethernet interface
   interface = &netInterface[0];

   //Set interface name
   netSetInterfaceName(interface, "eth0");
   //Set host name
   netSetHostname(interface, "RampaBus");
   //Select the relevant network adapter
   netSetDriver(interface, &stm32f4x7EthDriver);
   netSetPhyDriver(interface, &lan8720PhyDriver);
   //Set host MAC address
	 Campo_Valor(&fi,"MAC","direccion",buf);
	 //TRACE_ERROR("valor de linea....=%s \r\n",buf);
	 macStringToAddr(buf,&macAddr);
   //macStringToAddr(APP_MAC_ADDR, &macAddr);
	 netSetMacAddr(interface, &macAddr);

   //Initialize network interface
   error = netConfigInterface(interface);
   //Any error to report?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to configure interface %s!\r\n", interface->name);
   }

	 Campo_Valor(&fi,"DHCP-CLIENT","active",buf);
	 TRACE_ERROR("valor de linea....=%d \r\n",atoi(buf));
	
#if (IPV4_SUPPORT == ENABLED)
//#if (APP_USE_DHCP == ENABLED)
   //Get default settings
	//Campo_Valor(&fi,"DHCP-CLIENT","active",buf); 
	if(atoi(buf)){
	
	 TRACE_ERROR("........MONTADO EN APP_USE_DHCP \r\n");
   dhcpClientGetDefaultSettings(&dhcpClientSettings);
   //Set the network interface to be configured by DHCP
   dhcpClientSettings.interface = interface;
   //Disable rapid commit option
   dhcpClientSettings.rapidCommit = FALSE;

   //DHCP client initialization
   error = dhcpClientInit(&dhcpClientContext, &dhcpClientSettings);
   //Failed to initialize DHCP client?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize DHCP client!\r\n");
   }

   //Start DHCP client
   error = dhcpClientStart(&dhcpClientContext);
   //Failed to start DHCP client?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to start DHCP client!\r\n");
   }
 }
 
//#else
 else{
   //Set IPv4 host address
	 Campo_Valor(&fi,"IPV4","ip_direccion",buf);
	 str_delcaracter(buf,buf,0xa);
	 
	 TRACE_ERROR("DIRECCION IP=%s \r\n",buf);
	 
	 ipv4StringToAddr(buf,&ipv4Addr);
   //ipv4StringToAddr(APP_IPV4_HOST_ADDR, &ipv4Addr);
   ipv4SetHostAddr(interface, ipv4Addr);

   //Set subnet mask
	 Campo_Valor(&fi,"IPV4","ip_submascara",buf);
	 str_delcaracter(buf,buf,0xa);
	 TRACE_ERROR("SUBMASK=%s \r\n",buf);
	 
	 ipv4StringToAddr(buf,&ipv4Addr);
   //ipv4StringToAddr(APP_IPV4_SUBNET_MASK, &ipv4Addr);
   ipv4SetSubnetMask(interface, ipv4Addr);

   //Set default gateway
	 Campo_Valor(&fi,"IPV4","ip_puertaenlace",buf);
	 str_delcaracter(buf,buf,0xa);
	 TRACE_ERROR("PUERTA DE ENLACE=%s \r\n",buf);
	 
	 ipv4StringToAddr(buf,&ipv4Addr);
   //ipv4StringToAddr(APP_IPV4_DEFAULT_GATEWAY, &ipv4Addr);
   ipv4SetDefaultGateway(interface, ipv4Addr);

   //Set primary and secondary DNS servers
	 Campo_Valor(&fi,"IPV4","ip_dns1",buf);
	 str_delcaracter(buf,buf,0xa);
	 TRACE_ERROR("DNS 1=%s \r\n",buf);
	 
	 ipv4StringToAddr(buf,&ipv4Addr);
   //ipv4StringToAddr(APP_IPV4_PRIMARY_DNS, &ipv4Addr);
   ipv4SetDnsServer(interface, 0, ipv4Addr);
	 
	 Campo_Valor(&fi,"IPV4","ip_dns2",buf);
	 str_delcaracter(buf,buf,0xa);
	 TRACE_ERROR("DNS 2=%s \r\n",buf);
	 
	 ipv4StringToAddr(buf,&ipv4Addr);
   //ipv4StringToAddr(APP_IPV4_SECONDARY_DNS, &ipv4Addr);
   ipv4SetDnsServer(interface, 1, ipv4Addr);
 }
//#endif
#endif

#if (IPV6_SUPPORT == ENABLED)
#if (APP_USE_SLAAC == ENABLED)
   //Get default settings
   slaacGetDefaultSettings(&slaacSettings);
   //Set the network interface to be configured
   slaacSettings.interface = interface;

   //SLAAC initialization
   error = slaacInit(&slaacContext, &slaacSettings);
   //Failed to initialize SLAAC?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize SLAAC!\r\n");
   }

   //Start IPv6 address autoconfiguration process
   error = slaacStart(&slaacContext);
   //Failed to start SLAAC process?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to start SLAAC!\r\n");
   }
#else
   //Set link-local address
   ipv6StringToAddr(APP_IPV6_LINK_LOCAL_ADDR, &ipv6Addr);
   ipv6SetLinkLocalAddr(interface, &ipv6Addr);

   //Set IPv6 prefix
   ipv6StringToAddr(APP_IPV6_PREFIX, &ipv6Addr);
   ipv6SetPrefix(interface, &ipv6Addr, APP_IPV6_PREFIX_LENGTH);

   //Set global address
   ipv6StringToAddr(APP_IPV6_GLOBAL_ADDR, &ipv6Addr);
   ipv6SetGlobalAddr(interface, &ipv6Addr);

   //Set router
   ipv6StringToAddr(APP_IPV6_ROUTER, &ipv6Addr);
   ipv6SetRouter(interface, &ipv6Addr);

   //Set primary and secondary DNS servers
   ipv6StringToAddr(APP_IPV6_PRIMARY_DNS, &ipv6Addr);
   ipv6SetDnsServer(interface, 0, &ipv6Addr);
   ipv6StringToAddr(APP_IPV6_SECONDARY_DNS, &ipv6Addr);
   ipv6SetDnsServer(interface, 1, &ipv6Addr);
#endif
#endif

		Cerrar_Archivo_Ini(&fi);
		
		PulgarRed();
/*
   //Get default settings
   ftpServerGetDefaultSettings(&ftpServerSettings);
   //Bind FTP server to the desired interface
   ftpServerSettings.interface = &netInterface[0];
   //Listen to port 21
   ftpServerSettings.port = FTP_PORT;
   //Root directory
   strcpy(ftpServerSettings.rootDir, "/");
   //User verification callback function
   ftpServerSettings.checkUserCallback = ftpServerCheckUserCallback;
   //Password verification callback function
   ftpServerSettings.checkPasswordCallback = ftpServerCheckPasswordCallback;
   //Callback used to retrieve file permissions
   ftpServerSettings.getFilePermCallback = ftpServerGetFilePermCallback;

   //FTP server initialization
   error = ftpServerInit(&ftpServerContext, &ftpServerSettings);
   //Failed to initialize FTP server?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize FTP server!\r\n");
   }

   //Start FTP server
   error = ftpServerStart(&ftpServerContext);
   //Failed to start FTP server?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to start FTP server!\r\n");
   }
*/
	 //Get default settings
   httpServerGetDefaultSettings(&httpServerSettings);


   //Bind HTTP server to the desired interface
   httpServerSettings.interface = &netInterface[0];
   //Listen to port 80
   httpServerSettings.port = HTTP_PORT;
	
	 
   //Client connections
   httpServerSettings.maxConnections = APP_HTTP_MAX_CONNECTIONS;
   httpServerSettings.connections = httpConnections;
   //Specify the server's root directory
   strcpy(httpServerSettings.rootDirectory, "/www/");
   //Set default home page
   strcpy(httpServerSettings.defaultDocument, "index.shtm");
   //Callback functions
   //httpServerSettings.cgiCallback = httpServerCgiCallback;
   httpServerSettings.uriNotFoundCallback = httpServerUriNotFoundCallback;
	 httpServerSettings.authCallback=httpServerAuthCallback;
   //HTTP server initialization
   error = httpServerInit(&httpServerContext, &httpServerSettings);
   //Failed to initialize HTTP server?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to initialize HTTP server!\r\n");
   }
	
   //Start HTTP server
   error = httpServerStart(&httpServerContext);
   //Failed to start HTTP server?
   if(error)
   {
      //Debug message
      TRACE_ERROR("Failed to start HTTP server!\r\n");
   }

   //Create user task
   task = osCreateTask("User Task", userTask, NULL, 300, 1);
   //Failed to create the task?
   if(task == OS_INVALID_HANDLE)
   {
      //Debug message
      TRACE_ERROR("Failed to create task!\r\n");
   }
		
/*
   //Create a task to blink the LED
   task = osCreateTask("Blink", blinkTask, NULL, 500, 1);
   //Failed to create the task?
   if(task == OS_INVALID_HANDLE)
   {
      //Debug message
      TRACE_ERROR("Failed to create task!\r\n");
   }
*/
   //Start the execution of tasks
   osStartKernel();

   //This function should never return
   return 0;
}


/**
 * @brief URI not found callback
 * @param[in] connection Handle referencing a client connection
 * @param[in] uri NULL-terminated string containing the path to the requested resource
 * @return Error code
 **/

error_t httpServerUriNotFoundCallback(HttpConnection *connection,
   const char_t *uri)
{
   //Not implemented
	 error_t error;
   uint_t n;
   char_t *buffer;
		
//		uint8_t buf[50];
		Capsula cap;
		uint16_t urojo=200,uverde=0,uazul=0,uuv=0,utp1,utp2,uhr1;
		uint16_t h_adc1,h_adc2,h_adc3,h_adc4;
		uint16_t vcont=0;
		uint32_t hor_fre=500;
		//float_t pin;
		uint8_t inque=0;
		
	 if(!strcasecmp(uri, "/OnOff.xml"))//error
   {
      //Point to the scratch buffer
      buffer = connection->buffer + 384;

      //Format XML data
      n = sprintf(buffer, "<data>\r\n");
      
      n += sprintf(buffer + n, "  <act>%u</act>\r\n", OnValue);
      
      //End of XML data
      n += sprintf(buffer + n, "</data>\r\n");

      //Format HTTP response header
      connection->response.version = connection->request.version;
      connection->response.statusCode = 200;
      connection->response.keepAlive = connection->request.keepAlive;
      connection->response.noCache = TRUE;
      connection->response.contentType = mimeGetType(".xml");
      connection->response.chunkedEncoding = FALSE;
      connection->response.contentLength = n;

      //Send the header to the client
      error = httpWriteHeader(connection);
      //Any error to report?
      if(error) return error;

      //Send response body
      error = httpWriteStream(connection, buffer, n);
      //Any error to report?
      if(error) return error;

      //Properly close output stream
      error = httpCloseStream(connection);
      //Return status code
      return error;
   }

	 else if(!strcasecmp(uri, "/sensores.xml"))//error
   {
     
			
			//if(pdTRUE==xQueueReceive(xQueueRampabus,buf,( portTickType ) 80/portTICK_RATE_MS)){
				
				
				DesModularMem(&urojo,sensortodo,2,0);
				DesModularMem(&uverde,sensortodo,2,2);
				DesModularMem(&uazul,sensortodo,2,4);
				DesModularMem(&uuv,sensortodo,2,6);
		 
		 
				/*
				DesModularMem(&urojo,sensor4,2,0);
				DesModularMem(&uverde,sensor4,2,2);
				DesModularMem(&uazul,sensor4,2,4);
				DesModularMem(&uuv,sensor4,2,6);
			*/
			
//				inque=1;
				//TRACE_INFO("SE TRANSMITE QUEUE RAMPABUS dir %d -- t1=%d -- h1=%d -- t2=%d\r\n",cap.Direccion,t1,h1,t2);
		//	}
		 
			 //Point to the scratch buffer
      buffer = connection->buffer + 384;
		 inque=1;
		 if(inque){
			//Format XML data
				n = sprintf(buffer, "<data>\r\n");
				n += sprintf(buffer + n, "  <rojo>%u</rojo>\r\n", urojo);
				n += sprintf(buffer + n, "  <verde>%d</verde>\r\n", uverde);
				n += sprintf(buffer + n, "  <azul>%d</azul>\r\n", uazul);
				n += sprintf(buffer + n, "  <uv>%d</uv>\r\n", uuv);
/*				
				n += sprintf(buffer + n, "  <tpa>%d</tpa>\r\n", utp1);
				n	+= sprintf(buffer + n, "	<tpb>%d</tpb>\r\n",	utp2);
				n	+= sprintf(buffer + n, "  <hr>%d</rh>\r\n", uhr1);
*/
				//End of XML data
				n += sprintf(buffer + n, "</data>\r\n");
			//	inque=0;
		 }
			
      //Format HTTP response header
      connection->response.version = connection->request.version;
      connection->response.statusCode = 200;
      connection->response.keepAlive = connection->request.keepAlive;
      connection->response.noCache = TRUE;
      connection->response.contentType = mimeGetType(".xml");
      connection->response.chunkedEncoding = FALSE;
      connection->response.contentLength = n;

      //Send the header to the client
      error = httpWriteHeader(connection);
      //Any error to report?
      if(error) return error;

      //Send response body
      error = httpWriteStream(connection, buffer, n);
      //Any error to report?
      if(error) return error;

      //Properly close output stream
      error = httpCloseStream(connection);
      //Return status code
      return error;
   }
	 else if(!strcasecmp(uri, "/sensores1_2.xml")){//error
			
			DesModularMem(&utp1,sensortodo,2,8);
			DesModularMem(&utp2,sensortodo,2,10);
			DesModularMem(&uhr1,sensortodo,2,12);
		 
			/*	
			DesModularMem(&utp1,sensor3,2,0);
			DesModularMem(&utp2,sensor3,2,2);
			DesModularMem(&uhr1,sensor3,2,4);
		*/
			
		 buffer = connection->buffer + 384;
		
		
			n = sprintf(buffer, "<data>\r\n");
			n += sprintf(buffer + n, "  <tp1>%u</tp1>\r\n", utp1);
			n += sprintf(buffer + n, "  <tp2>%d</tp2>\r\n", utp2);
			n += sprintf(buffer + n, "  <hr1>%d</hr1>\r\n", uhr1);


			n += sprintf(buffer + n, "</data>\r\n");
		
		 
			
      //Format HTTP response header
      connection->response.version = connection->request.version;
      connection->response.statusCode = 200;
      connection->response.keepAlive = connection->request.keepAlive;
      connection->response.noCache = TRUE;
      connection->response.contentType = mimeGetType(".xml");
      connection->response.chunkedEncoding = FALSE;
      connection->response.contentLength = n;

      
      error = httpWriteHeader(connection); //Send the header to the client
      if(error) return error; //Any error to report?
      error = httpWriteStream(connection, buffer, n);//Send response body
      if(error) return error;//Any error to report?
      error = httpCloseStream(connection);//Properly close output stream
		 
			//xSemaphoreGive(xSemaphoreSensores110);
      return error;//Return status code
			
	}
	 else if(!strcasecmp(uri,"/sensores1_3.xml")){//error
		// xSemaphoreGive(xSemaphoreHor);
		 
		
		 DesModularMem(&h_adc1,sensortodo,2,14);
		 DesModularMem(&h_adc2,sensortodo,2,16);
		 DesModularMem(&h_adc3,sensortodo,2,18);
		 DesModularMem(&h_adc4,sensortodo,2,20);
		 
		 /*
		 DesModularMem(&h_adc1,sensorhor,2,0);
		 DesModularMem(&h_adc2,sensorhor,2,2);
		 DesModularMem(&h_adc3,sensorhor,2,4);
		 DesModularMem(&h_adc4,sensorhor,2,6);
		*/
			
		 buffer = connection->buffer + 384;
/*			
		 h_adc1=10000;
		 h_adc2=20000;
		 h_adc3=30000;
		 h_adc4=40000;
*/		
		 n = sprintf(buffer, "<data>\r\n");
		 n += sprintf(buffer + n, "  <adc1>%u</adc1>\r\n", h_adc1);
		 n += sprintf(buffer + n, "  <adc2>%d</adc2>\r\n", h_adc2);
		 n += sprintf(buffer + n, "  <adc3>%d</adc3>\r\n", h_adc3);
		 n += sprintf(buffer + n, "  <adc4>%d</adc4>\r\n", h_adc4);


		 n += sprintf(buffer + n, "</data>\r\n");
		
		 
			
      //Format HTTP response header
      connection->response.version = connection->request.version;
      connection->response.statusCode = 200;
      connection->response.keepAlive = connection->request.keepAlive;
      connection->response.noCache = TRUE;
      connection->response.contentType = mimeGetType(".xml");
      connection->response.chunkedEncoding = FALSE;
      connection->response.contentLength = n;

      
      error = httpWriteHeader(connection); //Send the header to the client
      if(error) return error; //Any error to report?
      error = httpWriteStream(connection, buffer, n);//Send response body
      if(error) return error;//Any error to report?
      error = httpCloseStream(connection);//Properly close output stream
		 
			xSemaphoreGive(xSemaphoreSensores110);
      return error;//Return status code
		 
		 
	 }
//	 
	 else if(!strcasecmp(uri, "/led1.xml")){
		 char *separator;
     char *property;
     char *value;
		 buffer = connection->buffer;
		
		 
		 do
      {
         //Process HTTP request body
         while(1)
         {
            error = httpReadStream(connection, buffer,
               HTTP_SERVER_BUFFER_SIZE - 1, &n, HTTP_FLAG_BREAK('&'));
            //End of stream detected?
            if(error) break;

            //Properly terminate the string with a NULL character
            buffer[n] = '\0';
					 
					 

            //Remove the trailing ampersand
            if(n > 0 && buffer[n - 1] == '&')
               buffer[--n] = '\0';

            //Decode the percent-encoded string
            httpDecodePercentEncodedString(buffer, buffer, HTTP_SERVER_BUFFER_SIZE);
            //Check whether a separator is present
						
						
            separator = strchr(buffer, '=');
						

            //Separator found?
            if(separator) {
               //Split the line
               *separator = '\0';
               //Get property name and value
               property = strTrimWhitespace(buffer);
               value = strTrimWhitespace(separator +1);

               //Check property name
               if(!strcasecmp(property, "ld1")){
									TRACE_ERROR("valor de value=%s\r\n",value);
									if(strcmp("on",value)==0){
										STM_EVAL_LEDOn(LED4);//verde alto
										//STM_EVAL_LEDOn(LED3);//amarillo bajo
										//STM_EVAL_LEDOn(LED5);//rojo alto
										//STM_EVAL_LEDOn(LED6);//naranja alto
										OnValue=1;
										xSemaphoreGive(xSemaphoreRampabus);
										if(next==0)next=1;
										TRACE_INFO("SE ACTIVO RAMPABUS********************\r\n");
									
									}
									else if(strcmp("off",value)==0){
										STM_EVAL_LEDOff(LED4);
									
										OnValue=0;
										if(next==1)next=0;
										TRACE_INFO("SE PAUSO RAMPABUS********************\r\n");
									}
							 }
							 
						}
				 }
			}while(0);
			 //Free previously allocated memory
     // osFreeMem((void *)connection);
     return error;
	 
	 }
	 else if(!strcasecmp(uri,"/form_luztodo.xml")){
		 char *separator;
     char *property;
     char *value;
		
		 buffer = connection->buffer;
		 
		 do
      {
         //Process HTTP request body
         while(1)
         {
            error = httpReadStream(connection, buffer,
               HTTP_SERVER_BUFFER_SIZE - 1, &n, HTTP_FLAG_BREAK('&'));
            //End of stream detected?
            if(error) break;
            //Properly terminate the string with a NULL character
            buffer[n] = '\0';

            //Remove the trailing ampersand
            if(n > 0 && buffer[n - 1] == '&')
               buffer[--n] = '\0';

            //Decode the percent-encoded string
            httpDecodePercentEncodedString(buffer, buffer, HTTP_SERVER_BUFFER_SIZE);
            //Check whether a separator is present
	
            separator = strchr(buffer, '=');

            //Separator found?
            if(separator) {
               //Split the line
               *separator = '\0';
               //Get property name and value
               property = strTrimWhitespace(buffer);
               value = strTrimWhitespace(separator +1);

               //Check property name
								TRACE_ERROR("%s\r\n",value);
							 
               if(!strcasecmp(property, "lrojo")){
									urojo=atoi(value);
				 
							 }
							 else if(!strcasecmp(property,"lverde")){
								 uverde=atoi(value);
							 }
							 else if(!strcasecmp(property,"lazul")){
								 uazul=atoi(value);
							 }
							 else if(!strcasecmp(property,"luv")){
								 uuv=atoi(value);
							 }
							 
						}
				 }
			 
			}while(0);
			
			vcont=0;
			cap.Direccion=110;//direccion para el sensor led de prueba
			cap.Funcion=1;
			cap.Grupos=esclavo;
			cap.Tamdatas=8;//en bytes
			cap.Normas=inicio;
							
							
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&urojo,sizeof(urojo),&vcont);
			MemSecuencial(TX_Buf,&uverde,sizeof(uverde),&vcont);
			MemSecuencial(TX_Buf,&uazul,sizeof(uazul),&vcont);
			MemSecuencial(TX_Buf,&uuv,sizeof(uuv),&vcont);
										
			cap.Direccion=DIR;
			cap.Funcion=0;
			cap.Grupos=0;
			cap.Normas=final;
			cap.Tamdatas=0;
										
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
										
			ActivarEnvio();
			sleep(30);
			SendDmaTx((uint8_t*)&TX_Buf,Multiplo(vcont,5));
			sleep(30);
			DesactivarEnvio(); 
			
		 return error;
	 }
	 else if(!strcasecmp(uri,"/hor_en.xml")){
		 char *separator;
     char *property;
     char *value;
		
		 buffer = connection->buffer;
		 
		 do
      {
        while(1)
         {
            error = httpReadStream(connection, buffer,
            HTTP_SERVER_BUFFER_SIZE - 1, &n, HTTP_FLAG_BREAK('&'));
            if(error) break;
            buffer[n] = '\0';

            //Remove the trailing ampersand
            if(n > 0 && buffer[n - 1] == '&')
               buffer[--n] = '\0';

            //Decode the percent-encoded string
            httpDecodePercentEncodedString(buffer, buffer, HTTP_SERVER_BUFFER_SIZE);
            //Check whether a separator is present
	
            separator = strchr(buffer, '=');

            //Separator found?
            if(separator) {
               //Split the line
               *separator = '\0';
               //Get property name and value
               property = strTrimWhitespace(buffer);
               value = strTrimWhitespace(separator +1);

               //Check property name
								TRACE_ERROR("%s\r\n",value);
							 
               if(!strcasecmp(property, "lhor_on")){
									if(atoi(value)==0){
										cap.Direccion=70;
										cap.Funcion=1;
										cap.Grupos=esclavo;
										cap.Normas=inicio;
										cap.Tamdatas=0;
										
										MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
										
										ActivarEnvio();
										sleep(30);
										SendDmaTx((uint8_t*)&TX_Buf,Multiplo(vcont,5));
										sleep(30);
										DesactivarEnvio(); 
										
									}
								 
									else{
										cap.Direccion=70;
										cap.Funcion=2;
										cap.Grupos=esclavo;
										cap.Normas=inicio;
										cap.Tamdatas=0;
										
										MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
										
										ActivarEnvio();
										sleep(30);
										SendDmaTx((uint8_t*)&TX_Buf,Multiplo(vcont,5));
										sleep(30);
										DesactivarEnvio(); 
										
										
									}
									
							 }
							 
	
						}
				 }
			 
			}while(0);
			
			return error;
		 
	 }

	 else if(!strcasecmp(uri,"/hor_fun03.xml")){
		 char *separator;
     char *property;
     char *value;
		
		 buffer = connection->buffer;
		 
		 do
      {
        while(1)
         {
            error = httpReadStream(connection, buffer,
            HTTP_SERVER_BUFFER_SIZE - 1, &n, HTTP_FLAG_BREAK('&'));
            if(error) break;
            buffer[n] = '\0';

            //Remove the trailing ampersand
            if(n > 0 && buffer[n - 1] == '&')
               buffer[--n] = '\0';

            //Decode the percent-encoded string
            httpDecodePercentEncodedString(buffer, buffer, HTTP_SERVER_BUFFER_SIZE);
            //Check whether a separator is present
	
            separator = strchr(buffer, '=');

            //Separator found?
            if(separator) {
               //Split the line
               *separator = '\0';
               //Get property name and value
               property = strTrimWhitespace(buffer);
               value = strTrimWhitespace(separator +1);

               //Check property name
								TRACE_ERROR("%s\r\n",value);
							 
               if(!strcasecmp(property, "lfun3")){
									hor_fre=atoi(value);
				 
							 }
							 
	
						}
				 }
			 
			}while(0);
			
			vcont=0;
			cap.Direccion=70;//direccion para el sensor led de prueba
			cap.Funcion=3;
			cap.Grupos=esclavo;
			cap.Tamdatas=4;//en bytes
			cap.Normas=inicio;
							
							
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&hor_fre,sizeof(hor_fre),&vcont);
												
			cap.Direccion=DIR;
			cap.Funcion=0;
			cap.Grupos=0;
			cap.Normas=final;
			cap.Tamdatas=0;
										
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
										
			ActivarEnvio();
			sleep(30);
			SendDmaTx((uint8_t*)&TX_Buf,Multiplo(vcont,5));
			sleep(30);
			DesactivarEnvio(); 
			return error;
	 }
	 else if(!strcasecmp(uri,"/hor_fun05.xml")){
		 char *separator;
     char *property;
     char *value;
		
		 buffer = connection->buffer;
		 
		 do
      {
        while(1)
         {
            error = httpReadStream(connection, buffer,
               HTTP_SERVER_BUFFER_SIZE - 1, &n, HTTP_FLAG_BREAK('&'));
            if(error) break;
            buffer[n] = '\0';

            //Remove the trailing ampersand
            if(n > 0 && buffer[n - 1] == '&')
               buffer[--n] = '\0';

            //Decode the percent-encoded string
            httpDecodePercentEncodedString(buffer, buffer, HTTP_SERVER_BUFFER_SIZE);
            //Check whether a separator is present
	
            separator = strchr(buffer, '=');

            //Separator found?
            if(separator) {
               //Split the line
               *separator = '\0';
               //Get property name and value
               property = strTrimWhitespace(buffer);
               value = strTrimWhitespace(separator +1);

               //Check property name
								TRACE_ERROR("%s\r\n",value);
							 
               if(!strcasecmp(property, "lfun5")){
									hor_fre=atoi(value);
				 
							 }
							 
							 
							 
							 
							 
							 
						}
				 }
			 
			}while(0);
			
			vcont=0;
			cap.Direccion=70;//direccion para el sensor led de prueba
			cap.Funcion=5;
			cap.Grupos=esclavo;
			cap.Tamdatas=4;//en bytes
			cap.Normas=inicio;
							
							
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
			MemSecuencial(TX_Buf,&hor_fre,sizeof(hor_fre),&vcont);
												
			cap.Direccion=DIR;
			cap.Funcion=0;
			cap.Grupos=0;
			cap.Normas=final;
			cap.Tamdatas=0;
										
			MemSecuencial(TX_Buf,&cap,sizeof(cap),&vcont);
										
			ActivarEnvio();
			sleep(30);
			SendDmaTx((uint8_t*)&TX_Buf,Multiplo(vcont,5));
			sleep(30);
			DesactivarEnvio(); 
			return error;
	 }
	 
	 else if(!strcasecmp(uri,"/btled1.xml")){
		 if(led1==0){
			 STM_EVAL_LEDOn(LED3);
			 led1=1;
		 } 
		 else{
			 STM_EVAL_LEDOff(LED3);
			led1=0;
		 }			
		 
		// return error;
	 }
	 else if(!strcasecmp(uri,"/btled2.xml")){
		  if(led2==0){
			 STM_EVAL_LEDOn(LED5);
			 led2=1;
		 } 
		 else{
			STM_EVAL_LEDOff(LED5);
			led2=0;
		 }
		 //return error;
	 }
	 else if(!strcasecmp(uri,"/btled3.xml")){
		  if(led3==0){
			 STM_EVAL_LEDOn(LED6);
			 led3=1;
		 } 
		 else{
			 STM_EVAL_LEDOff(LED6);
			led3=0;
		 }
		 //return error;
	 }
	
		
		return ERROR_NOT_FOUND;
	
}


HttpAccessStatus httpServerAuthCallback(HttpConnection *connection,
   const char_t *user, const char_t *uri)
{
   HttpAccessStatus status;

   //Manage access rights
   if(pathMatch(uri, "/passwords.txt")){
      //This file is not visible
      status = HTTP_ACCESS_DENIED;
   }
   else if(pathMatch(uri, "/config/*")){
      //This directory is not visible
      status = HTTP_ACCESS_DENIED;
   }
   else if(pathMatch(uri, "/admin/*")){
      //Only the administrator can access this directory
      if(!strcmp(user, "administrator")){
         //Check the administrator password
         if(httpCheckPassword(connection, "password", HTTP_AUTH_MODE_BASIC))
            status = HTTP_ACCESS_ALLOWED;
         else
            status = HTTP_ACCESS_BASIC_AUTH_REQUIRED;
      }
      else {
         //Users other than administrator cannot access this directory
         status = HTTP_ACCESS_BASIC_AUTH_REQUIRED;
      }
   }
   else {
      //No restriction for other directories
     status = HTTP_ACCESS_ALLOWED;
		 //status = HTTP_ACCESS_DENIED;
   }

   //Return access status
   return status;
}




/*
error_t httpServerCgiCallback(HttpConnection *connection,
   const char_t *param)
{
	
   static uint_t pageCounter = 0;
   uint_t length;

   //Underlying network interface
   NetInterface *interface = connection->socket->interface;

	 
   //Check parameter name
	
		
	
   if(!strcasecmp(param, "PAGE_COUNTER"))
   {
      pageCounter++;
      sprintf(connection->buffer, "%u time%s", pageCounter, (pageCounter >= 2) ? "s" : "");
   }
   else if(!strcasecmp(param, "BOARD_NAME"))
   {
      strcpy(connection->buffer, "STM32F4-Discovery");
   }
   else if(!strcasecmp(param, "SYSTEM_TIME"))
   {
      systime_t time = osGetSystemTime();
      formatSystemTime(time, connection->buffer);
   }
   else if(!strcasecmp(param, "MAC_ADDR"))
   {
      macAddrToString(&interface->macAddr, connection->buffer);
   }
   else if(!strcasecmp(param, "IPV4_ADDR"))
   {
      ipv4AddrToString(interface->ipv4Config.addr, connection->buffer);
   }
   else if(!strcasecmp(param, "SUBNET_MASK"))
   {
      ipv4AddrToString(interface->ipv4Config.subnetMask, connection->buffer);
   }
   else if(!strcasecmp(param, "DEFAULT_GATEWAY"))
   {
      ipv4AddrToString(interface->ipv4Config.defaultGateway, connection->buffer);
   }
   else if(!strcasecmp(param, "IPV4_PRIMARY_DNS"))
   {
      ipv4AddrToString(interface->ipv4Config.dnsServer[0], connection->buffer);
   }
   else if(!strcasecmp(param, "IPV4_SECONDARY_DNS"))
   {
      ipv4AddrToString(interface->ipv4Config.dnsServer[1], connection->buffer);
   }
#if (IPV6_SUPPORT == ENABLED)
   else if(!strcasecmp(param, "LINK_LOCAL_ADDR"))
   {
      ipv6AddrToString(&interface->ipv6Config.linkLocalAddr, connection->buffer);
   }
   else if(!strcasecmp(param, "GLOBAL_ADDR"))
   {
      ipv6AddrToString(&interface->ipv6Config.globalAddr, connection->buffer);
   }
   else if(!strcasecmp(param, "IPV6_PREFIX"))
   {
      ipv6AddrToString(&interface->ipv6Config.prefix, connection->buffer);
      length = strlen(connection->buffer);
      sprintf(connection->buffer + length, "/%u", interface->ipv6Config.prefixLength);
   }
   else if(!strcasecmp(param, "ROUTER"))
   {
      ipv6AddrToString(&interface->ipv6Config.router, connection->buffer);
   }
   else if(!strcasecmp(param, "IPV6_PRIMARY_DNS"))
   {
      ipv6AddrToString(&interface->ipv6Config.dnsServer[0], connection->buffer);
   }
   else if(!strcasecmp(param, "IPV6_SECONDARY_DNS"))
   {
      ipv6AddrToString(&interface->ipv6Config.dnsServer[1], connection->buffer);
   }
#endif
   else
   {
      return ERROR_INVALID_TAG;
   }

   //Get the length of the resulting string
   length = strlen(connection->buffer);

   //Send the contents of the specified environment variable
   return httpWriteStream(connection, connection->buffer, length);
	 
	 
}

*/

/**
 * @brief User verification callback function
 * @param[in] connection Handle referencing a client connection
 * @param[in] user NULL-terminated string that contains the user name
 * @return Access status (FTP_ACCESS_ALLOWED, FTP_ACCESS_DENIED or FTP_PASSWORD_REQUIRED)
 **/
/*
uint_t ftpServerCheckUserCallback(FtpClientConnection *connection,
   const char_t *user)
{
   //Debug message
   TRACE_INFO("FTP server: User verification\r\n");

   //Manage authentication policy
   if(!strcmp(user, "anonymous"))
   {
      return FTP_ACCESS_ALLOWED;
   }
   else if(!strcmp(user, "admin"))
   {
      return FTP_PASSWORD_REQUIRED;
   }
   else
   {
      return FTP_ACCESS_DENIED;
   }
}
*/

/**
 * @brief Password verification callback function
 * @param[in] connection Handle referencing a client connection
 * @param[in] user NULL-terminated string that contains the user name
 * @param[in] password NULL-terminated string that contains the corresponding password
 * @return Access status (FTP_ACCESS_ALLOWED or FTP_ACCESS_DENIED)
 **/
/*
uint_t ftpServerCheckPasswordCallback(FtpClientConnection *connection,
   const char_t *user, const char_t *password)
{
   //Debug message
   TRACE_INFO("FTP server: Password verification\r\n");

   //Verify password
   if(!strcmp(user, "admin") && !strcmp(password, "admin"))
   {
      return FTP_ACCESS_ALLOWED;
   }
   else
   {
      return FTP_ACCESS_DENIED;
   }
}
*/

/*
void userTask_xxx(void *param)
{
		
	Capsula cap ;
	CapFile capfi;
	uint8_t bbuf[50];
	//uint8_t bbfu2[100];
	uint8_t next=1;
	portTickType tick;
	uint16_t  rpin;	
//	uint16_t t1,h1,t2;
	
	TRACE_ERROR("*******************ENTRANDO A USERTASK*********************\r\n");
	sleep(8000);
	//DMA_Cmd(DMA1_Stream1,DISABLE);
	PulgarRed();
	
	TNV_Cabecera_INI_FIN(0);
		
	while(1){
		
		while(next){
			if(OnValue==0)xSemaphoreTake( xSemaphoreRampabus, ( portTickType ) portMAX_DELAY );
			TNV_ObtenerTarea(bbuf,&capfi);
			DesModularMem(&cap,bbuf,sizeof(cap),0);

			if(cap.Funcion==1){
				
				Config_USART3_DMA_RX(5);
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
				tick = xTaskGetTickCount();
				xSemaphoreTake( xSemaphoreUSART3, ( portTickType ) portMAX_DELAY );
				
				DesModularMem(&rpin,RX_Buf,2,0);
				osDelayTask(15);
				//TRACE_ERROR("VAlor de direccion=%d y rpin=%x\r\n",cap.Direccion,rpin);
				if(cap.Direccion==150 && rpin==0xfafb){
					GPIOD->ODR^=GPIO_Pin_12;
					memset(RX_Buf,0,5);
				}
				else if(cap.Direccion==151 && rpin==0xfafb){
					GPIOD->ODR^=GPIO_Pin_13;
					memset(RX_Buf,0,5);
				}
				tick=xTaskGetTickCount()-tick;
				vTaskDelayUntil(&tick,1/portTICK_RATE_MS);
				tran_time=(float_t)tick;
				tick=0;
			}
			else if(cap.Funcion==2){
				
				Config_USART3_DMA_RX(Multiplo(11,5));
				
				ActivarEnvio();
				sleep(30);
				SendDmaTx((uint8_t*)&cap,sizeof(cap));
				sleep(30);
				DesactivarEnvio();
				sleep(30);
				
				
				xSemaphoreTake( xSemaphoreUSART3, ( portTickType ) portMAX_DELAY );
				
				xQueueSendToBack(xQueueRampabus,RX_Buf,( portTickType ) portMAX_DELAY);
				
				memset(RX_Buf,0,15);
				
			}
			
			next=TNV_Sig();
			//sleep(100);
			osDelayTask(100);
			
		}
		TNV_Cabecera_INI_FIN(0);
		//next=1;
		
		
	}
}
	
*/

/**
 * @brief Callback used to retrieve file permissions
 * @param[in] connection Handle referencing a client connection
 * @param[in] user NULL-terminated string that contains the user name
 * @param[in] path Canonical path of the file
 * @return Permissions for the specified file
 **/
/*
uint_t ftpServerGetFilePermCallback(FtpClientConnection *connection,
   const char_t *user, const char_t *path)
{
   uint_t perm;

   //Debug message
   TRACE_INFO("FTP server: Checking access rights for %s\r\n", path);

   //Manage access rights
   if(!strcmp(user, "anonymous"))
   {
      //Allow read/write access to temp directory
      if(pathMatch(path, "/temp/*"))
         perm = FTP_FILE_PERM_LIST | FTP_FILE_PERM_READ | FTP_FILE_PERM_WRITE;
      //Allow read access only to other directories
      else
         perm = FTP_FILE_PERM_LIST | FTP_FILE_PERM_READ;
   }
   else if(!strcmp(user, "admin"))
   {
      //Allow read/write access
      perm = FTP_FILE_PERM_LIST | FTP_FILE_PERM_READ | FTP_FILE_PERM_WRITE;
   }
   else
   {
      //Deny access
      perm = 0;
   }

   //Return the relevant permissions
   return perm;
}
*/
